@@ -15,6 +15,9 @@
 
 
 
+;; For internationalisation
+(define _ gettext)
+
 
 
 ;; Direct access to a cube object. It is assumed the user knows what he is doing
@@ -44,7 +47,7 @@
 (define (check-cube-structure cube)
   (if (equal? (car cube) '(1 3 3 3 3))
       #t
-      (begin (gnubik-error-dialog "This script only works on 3x3x3 cubes.")
+      (begin (gnubik-error-dialog (_ "This script only works on 3×3×3 cubes."))
              #f)))
 
 
@@ -261,7 +264,7 @@
 
 (define move-buffer '())
 (define (execute-move-buffer!)
-  (gnubik-rotate-animated (reverse! move-buffer))
+  (gnubik-append-moves (reverse! move-buffer))
   (set! move-buffer '()))
 (define (clear-move-buffer!)
   (set! move-buffer '()))
@@ -271,7 +274,7 @@
 
 ;; A procedure which applies the above function for specific symbolic move
 ;; names. It also returns an entry that should be passed in a list to
-;; gnubik-rotate-animated et al., to cause the cube to be rotated in the C world
+;; gnubik-append-moves et al., to cause the cube to be rotated in the C world
 ;; also (the correspondence between the scheme moves and those in the C world
 ;; have been determined by trial and error).
 ;;
