@@ -13,9 +13,6 @@
 ;;   You should have received a copy of the GNU General Public License
 ;;   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
-
-
 ;; I'm not normally one for global variables, but this is so pervasive
 ;; throughout this unit I couldn't resist. It is the scheme reflection of
 ;; GNUbik's own cube object.
@@ -397,17 +394,30 @@
 ;; Provide plenty of menu entries to give the user some control over the solving
 ;; algorithm (he may want to perform part of the solution himself!)
 
-(gnubik-register-script "_Solvers/_3x3/_Mellor (baseline)/_Full cube"
-                        "mellor-solve 7")
-(gnubik-register-script "_Solvers/_3x3/_Mellor (baseline)/Bottom edge place"
-                        "mellor-solve 6")
-(gnubik-register-script "_Solvers/_3x3/_Mellor (baseline)/Bottom corner orient"
-                        "mellor-solve 5")
-(gnubik-register-script "_Solvers/_3x3/_Mellor (baseline)/Bottom corner place"
-                        "mellor-solve 4")
-(gnubik-register-script "_Solvers/_3x3/_Mellor (baseline)/_Middle slice"
-                        "mellor-solve 3")
-(gnubik-register-script "_Solvers/_3x3/_Mellor (baseline)/_Top slice"
-                        "mellor-solve 2")
-(gnubik-register-script "_Solvers/_3x3/_Mellor (baseline)/_Top edges"
-                        "mellor-solve 1")
+(define _ gettext)
+
+(define solvers (gnubik-create-menu (_ "_Solvers")))
+(define m3 (gnubik-create-menu (_ "_3×3") solvers))
+(define menu (gnubik-create-menu "_Mellor" m3))
+
+
+(gnubik-register-script (_ "_Full cube")
+                        '(mellor-solve 7) menu)
+
+(gnubik-register-script (_ "Bottom _edge place")
+                        '(mellor-solve 6) menu)
+
+(gnubik-register-script (_ "Bottom _corner orient")
+                        '(mellor-solve 5) menu)
+
+(gnubik-register-script (_ "_Bottom corner place")
+                        '(mellor-solve 4) menu)
+
+(gnubik-register-script (_ "_Middle slice")
+                        '(mellor-solve 3) menu)
+
+(gnubik-register-script (_ "_Top slice")
+                        '(mellor-solve 2) menu)
+
+(gnubik-register-script (_ "_Top edges")
+                        '(mellor-solve 1) menu)
