@@ -1,6 +1,6 @@
 /*
     GNUbik -- A 3 dimensional magic cube game.
-    Copyright (C) 2003  John Darrington
+    Copyright (C) 2003, 2011  John Darrington
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,26 +19,10 @@
 #ifndef GLAREA_H
 #define GLAREA_H
 
-#include <gtk/gtk.h>
+#include "cubeview.h"
 
-
-extern GLdouble fovy;
-extern GLdouble cp_near,  cp_far;
-
-
-void re_initialize_glarea (void);
-
-
-void register_gl_callbacks (GtkWidget * glxarea);
-GtkWidget * create_gl_area (GtkWidget * containerWidget,  GtkWidget * adjacentWidget);
-
-
-void modelViewInit (void);
-
-void postRedisplay (void);
-
-void lighting_init (void);
-
-void projection_init (int jitter);
+void perspectiveSet (struct scene_view *);
+void scene_init (GbkCubeview *);
+void projection_init (struct scene_view *, int jitter);
 
 #endif
